<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Щелкните на иконке в системном лотке
или снова нажмите на ярлык программы для остановки записи</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Не поворачивайте экран во время записи</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Запись</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Захват экрана</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Сохранение не удалось. Пожалуйста, сохраните файл в своем домашнем каталоге</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Завершение процесса скриншота</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Выберите область</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сохранить в %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорировать</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Буфер обмена</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Сохранение файла записи с экрана, пожалуйста подождите...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Поскольку эффект окна отключен во время процесса записи, запись должна быть остановлена</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Скриншот с прокруткой</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Закрепить скриншоты</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Скриншот завершен и скопирован в буфер обмена</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Закрепить скриншоты</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Запись</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Запись завершена</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сохранить в %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Открыть папку</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Захват экрана начнется через %1 секунды</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Получить справку.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Не удалось сделать непрерывный скриншот.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Достигнут низ области прокрутки</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Достигнута максимальная длина</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>для изменения области захвата</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Прокрутите колесо мыши или щелкните, чтобы сделать прокручиваемый скриншот</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Замедлить прокрутку</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Неверная область, щелкните</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Введите текст здесь</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Пуск / Скриншот</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Выход/Сохранение</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Настройка размера</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Быстрый пуск</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Скриншот окна</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Скриншот с задержкой</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Скриншот всего экрана</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Растянуть вверх</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Растянуть вниз</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Растянуть влево</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Растянуть вправо</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Уменьшить размер  сверху</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Уменьшить размер снизу</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Уменьшить ширину слева</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Уменьшить ширину справа</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показать комбинации клавиш</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Клавиатурный ввод</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Веб-камера</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Начало записи</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Старт/Запись</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Мышь</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Извлечь текст</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Скриншот с прокруткой</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Закрепить скриншоты</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Запустить OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Запустить прокручиваемый скриншот</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрелка</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Прямоугольник
Удерживайте Shift, чтобы нарисовать квадрат</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Эллипс
Удерживайте Shift, чтобы нарисовать окружность</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Кисть
Удерживайте Shift, чтобы нарисовать прямую линию</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Настройте силу размытия (прокрутите, чтобы скорректировать)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Настройте размер кисти (прокрутите, чтобы скорректировать)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Настройте размер текста (прокрутите, чтобы скорректировать)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Показать клавиатурный ввод (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Скрыть клавиатурный ввод (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Показать клавиатурный ввод (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Включить камеру (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Выключить камеру (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Настройки (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>Кадры в секунду:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Микрофон</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Звук системы</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Показать указатель</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Показать щелчок</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Сохранить в</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Линия (L)
Нажмите и удерживайте Shift, чтобы нарисовать вертикальную или горизонтальную линию</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Стрелка (X)
Нажмите и удерживайте Shift, чтобы нарисовать вертикальную или горизонтальную стрелку</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Карандаш (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Размытие (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Текст (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Скриншот с прокруткой (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Извлечь текст (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Закрепить скриншоты (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Отмена (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Установить путь при сохранении</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Изменить путь при сохранении</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Эффект краев</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Тень</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Граница</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Извлечь Текст</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Геометрические инструменты (R)
Удерживайте Shift для рисования квадратов или кругов.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Сохранить локально</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Сохранить на рабочий стол</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Сохранить в изображения</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Сохранить в %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Указанное место</translation>
    </message>
    <message>
        <source>Custom Location</source>
        <translation>Пользовательское место</translation>
    </message>
    <message>
        <source>Each inquiry</source>
        <translation>Каждый запрос</translation>
    </message>
    <message>
        <source>Update location on save</source>
        <translation>Обновить место при сохранении</translation>
    </message>
    <message>
        <source>Save to desktop</source>
        <translation>Сохранить на рабочий стол</translation>
    </message>
    <message>
        <source>Save to pictures</source>
        <translation>Сохранить в изображения</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Закрыть (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Скопировать в буфер обмена (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Отрегулируйте область записи в пределах %1*%2, чтобы получить лучший видеоэффект</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>На данный момент запись экрана не поддерживается</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
</TS>
